===============
Django-rgallery
===============

It's just another django gallery application. Get ready to store your photos
and organize them by tags and/or folders.

Contents
========

.. toctree::
 :maxdepth: 2

 quickstart
 settings
 backends
 commands
 contributing
 changelog
 todo